@@ -1194,13 +1194,16 @@ class Manaba:
                 raise ManabaInternalError(
                     "get_task_status return None (" + statuses[0].strip() + ")")
 
-            if "まだ提出は可能です" not in statuses[1]:  # 未提出 & ※遅延として取り扱われますが、まだ提出は可能です。
+            your_status: Optional[ManabaTaskYourStatusFlag]
+            if "まだ提出は可能です" in statuses[1]:  # 未提出 & ※遅延として取り扱われますが、まだ提出は可能です。
+                your_status = ManabaTaskYourStatusFlag.UNSUBMITTED
+            elif "回提出済み" in statuses[1]:  # ドリル対策。未合格で締め切られている場合「n回提出済み」になる？
+                your_status = ManabaTaskYourStatusFlag.UNPASSED
+            else:
                 your_status = get_your_status(statuses[1].strip())
                 if your_status is None:
                     raise ManabaInternalError(
                         "your_status return None (" + statuses[1].strip() + ")")
-            else:
-                your_status = ManabaTaskYourStatusFlag.UNSUBMITTED
 
             return ManabaTaskStatus(task_status, your_status)
 
